@@ -6,6 +6,8 @@ from unsafe.utils.wp import Wordpress
 from unsafe.utils.exifdata import ExifImage
 from unsafe.utils.anonymous import Anonymous
 from unsafe.utils.seeker import Seeker
+from queue import Queue
+
 
 class Unsafe(
     Encryptor,
@@ -17,4 +19,10 @@ class Unsafe(
     Anonymous,
     Seeker
 ):
-    ...
+    def __init__(self):
+        self.admin_finder_queue = Queue()
+        self.file_manager_queue = Queue()
+        self.cloudflare_subdomain_bypasser = Queue()
+        self.admin_finder_founded = []
+        self.file_manager_founded = []
+        self.subdomain_bypassed = {}
